#
# ora_secured::controls::admin_restrictions_is_set_to_on
#
# @summary The `admin_restrictions_<listener_name>` setting in the `listener.
# ora` file can
# require that any attempted real-time alteration of the parameters in the
# listener via the set command file be refused unless the `listener.ora` file is
# manually altered, then restarted by a privileged user.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.1.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.1.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.1.2
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.1.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::admin_restrictions_is_set_to_on: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::admin_restrictions_is_set_to_on::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `admin_restrictions_is_set_to_on` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::admin_restrictions_is_set_to_on (
  String $listener_ora_custom  = ora_secured::lookup_setting('listener_ora_custom', ''),
  String $listener_name_custom = ora_secured::lookup_setting('listener_name_custom', ''),
) {
  $sid = $title
  ora_secured_setup { "admin_restrictions_is_set_to_on on ${sid}":
    ensure => 'present',
  }

  $oracle_version = ora_config::on_sid($facts['ora_version'], $sid)[0]
  if $oracle_version == undef {
    debug 'Rule needs a running Oracle to determine Oracle version.'
  } else {
    # If no listener_name is specified use facts
    if empty($listener_name_custom) {
      $listener_name = $facts['ora_listener_name']
    } else {
      $listener_name = $listener_name_custom
    }

    # If no listener_ora path is specified use facts
    if empty($listener_ora_custom) {
      $listener_ora = $facts['ora_listener_parameter_file']
    } else {
      $listener_ora = $listener_ora_custom
    }

    # Set admin_restrictions to ON
    file_line { "admin_restrictions_is_set_to_on@${sid}":
      ensure                                => present,
      path                                  => $listener_ora,
      line                                  => "ADMIN_RESTRICTIONS_${listener_name} = ON",
      match                                 => "ADMIN_RESTRICTIONS_${listener_name}.*",
      replace_all_matches_not_matching_line => true,
    }
  }
}
