#
# ora_secured::controls::all_is_revoked_on_sensitive_tables
#
# @summary The Oracle database tables listed below may contain sensitive information, and
# should not be accessible to unauthorized users.
# 
# - `USER$`, `USER_HISTORY$`, `XS$VERIFIERS` and `DEFAULT_PWD$` may contain
#   password hashes.
# - `CDB_LOCAL_ADMINAUTH$` and `PDB_SYNC$` may contain DDLs.
# - `LINK$` and `SCHEDULER$_CREDENTIA`L may contain encrypted passwords.
# - `ENC$` may contains encryption keys.
# - `HISTGRM$` and `HIST_HEAD$` may contain sensitive data.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.3.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.3.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.3.3
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.3.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::all_is_revoked_on_sensitive_tables: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::all_is_revoked_on_sensitive_tables::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_is_revoked_on_sensitive_tables` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::all_is_revoked_on_sensitive_tables (
  Array $list    = ora_secured::lookup_setting('list', undef),
  Array $exclude = ora_secured::lookup_setting('exclude', [])
) {
  $sid = $title

  ora_secured_setup { "all_is_revoked_on_sensitive_tables on ${sid}":
    ensure => 'present',
  }

  $user_role_list = ora_config::on_sid($facts['ora_non_maintained_users_roles'], $sid) + $exclude
  $user_role_list.each |$user_role| {
    $list.each |$object| {
      ora_object_grant { "${user_role}->SYS.${object}@${sid}":
        permissions => [],
      }
    }
  }
}
