#
# ora_secured::controls::automatically_audit_account_termination
#
# @summary Check Oracle settings (and also OS settings and/or enterprise-level authentication/access mechanisms settings) to determine if account termination actions are being audited.
# If account termination actions are not being audited by Oracle, this is a finding.
# 
# If Standard Auditing is used:
# To see if Oracle is configured to capture audit data, enter the following SQL*Plus command:
# SHOW PARAMETER AUDIT_TRAIL
# or the following SQL query:
# SELECT * FROM SYS.V$PARAMETER WHERE NAME = 'audit_trail';
# If Oracle returns the value 'NONE', this is a finding.
# 
# If Unified Auditing is used:
# To see if Oracle is configured to capture audit data including account termination, enter the following SQL*Plus command:
# SELECT ' Account termination is not being audited. ' 
# FROM   dual 
# WHERE  (SELECT Count(*)
#         FROM   (select policy_name , audit_option from audit_unified_policies
#         WHERE  audit_option = 'DROP USER'
#         and policy_name in (select policy_name from audit_unified_enabled_policies where user_name='ALL USERS'))) = 0
#         OR (SELECT value 
#             FROM   v$option 
#             WHERE  parameter = 'Unified Auditing') != 'TRUE';  
# 
# If Oracle returns "no rows selected", this is not a finding.
# 
# Configure Oracle to audit account termination actions.
# 
# If Standard Auditing is used:
# Use this process to ensure auditable events are captured:
# ALTER SYSTEM SET AUDIT_TRAIL=<audit trail type> SCOPE=SPFILE;
# Audit trail type can be 'OS', 'DB', 'DB,EXTENDED', 'XML' or 'XML,EXTENDED'.
# After executing this statement, it may be necessary to shut down and restart the Oracle database.
# 
# If Unified Auditing is used:
# To ensure auditable events are captured:
# Link the oracle binary with uniaud_on, and then restart the database. Oracle Database Upgrade Guide describes how to enable unified auditing.  Reference V-61625 for information on how to configure a policy to audit account termination.
# 
# For more information on the configuration of auditing, refer to the following documents:
# "Auditing Database Activity" in the Oracle Database 2 Day + Security Guide:
# http://docs.oracle.com/database/121/TDPSG/tdpsg_auditing.htm#TDPSG50000
# "Monitoring Database Activity with Auditing" in the Oracle Database Security Guide:
# http://docs.oracle.com/database/121/DBSEG/part_6.htm#CCHEHCGI
# "DBMS_AUDIT_MGMT" in the Oracle Database PL/SQL Packages and Types Reference:
# http://docs.oracle.com/database/121/ARPLS/d_audit_mgmt.htm#ARPLS241
# Oracle Database Upgrade Guide:
# http://docs.oracle.com/database/121/UPGRD/afterup.htm#UPGRD52810
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::automatically_audit_account_termination: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::automatically_audit_account_termination::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `automatically_audit_account_termination` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61573
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::automatically_audit_account_termination {
  ora_secured_setup { "automatically_audit_account_termination on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
