#
# ora_secured::controls::database_backup_procedures_must_be_defined_documented_and_implemented
#
# @summary Review the database backup procedures and implementation evidence.
# Evidence of implementation includes records of backup events and physical review of backup media.
# 
# Evidence should match the backup plan as recorded in the system documentation.
# 
# If backup procedures do not exist or are not implemented in accordance with the procedures, this is a finding.
# 
# - - - - -
# The Oracle recommended process for backup and recovery is Oracle RMAN. If Oracle RMAN is deployed, execute the following commands to ensure that the evidence of the implementation of the backup policy includes validating that the files are restorable:
# 
# Validating Database Files with BACKUP VALIDATE
# --Use the BACKUP VALIDATE command to do the following:
# --Check datafiles for physical and logical block corruption
# --Confirm that all database files exist and are in the correct locations
# --When BACKUP VALIDATE is run, RMAN reads the files to be backed up in their entirety, as it would during a real backup. RMAN does not, however, actually produce any backup sets or image copies.
# --Cannot use the BACKUPSET, MAXCORRUPT, or PROXY parameters with BACKUP VALIDATE.
# --To validate files with the BACKUP VALIDATE command:
#   1. Start RMAN and connect to a target database and recovery catalog (if used).
#   2. Run the BACKUP VALIDATE command.
# 
# For example, can validate that all database files and archived logs can be backed up by running a command as shown in the following example. This command checks for physical corruptions only.
# 
# BACKUP VALIDATE
# DATABASE
# ARCHIVELOG ALL;
# 
# To check for logical corruptions in addition to physical corruptions, run the  following variation of the preceding command:
# 
# BACKUP VALIDATE
# CHECK LOGICAL
# DATABASE
# ARCHIVELOG ALL;
# 
# In the preceding examples, the RMAN client displays the same output that it would if it were really backing up the files. If RMAN cannot back up one or more of the files, then it issues an error message.
# 
# Validating Backups Before Restoring Them
# 
# Run RESTORE ... VALIDATE to test whether RMAN can restore a specific file or set of files from a backup. RMAN chooses which backups to use. The database must be mounted or open for this command. Do not have to take datafiles off-line when validating the restore of datafiles, because validation of backups of the datafiles only reads the backups and does not affect the production datafiles. When validating files on disk or tape, RMAN reads all blocks in the backup piece or image copy. RMAN also validates off-site backups. The validation is identical to a real restore operation except that RMAN does not write output files.
# 
# To validate backups with the RESTORE command:
# 1. Run the RESTORE command with the VALIDATE option.
# 
# This following example illustrates validating the restore of the database and all archived redo logs:
# 
# RESTORE DATABASE VALIDATE;
# RESTORE ARCHIVELOG ALL VALIDATE;
# 
# If an RMAN error stack is not generated, then skip the subsequent steps. The lack of error messages means that RMAN had confirmed that it can use these backups successfully during a real restore and recovery.
# 
# 2. If error messages are seen in the output and one is the RMAN-06026 message, then investigate the cause of the problem. If possible, correct the problem that is preventing RMAN from validating the backups and retry the validation. The following error means that RMAN cannot restore one or more of the specified files from available backups:
# 
# RMAN-06026: some targets not found - aborting restore
# The following sample output shows that RMAN encountered a problem reading the specified backup:
# 
# RMAN-03009: failure of restore command on c1 channel at 12-DEC-14 23:22:30
# ORA-19505: failed to identify file "oracle/dbs/1fafv9gl_1_1"
# ORA-27037: unable to obtain file status
# SVR4 Error: 2: No such file or directory
# Additional information: 3
# 
# Develop, document, and implement database backup procedures.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::database_backup_procedures_must_be_defined_documented_and_implemented: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::database_backup_procedures_must_be_defined_documented_and_implemented::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_backup_procedures_must_be_defined_documented_and_implemented` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61695
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::database_backup_procedures_must_be_defined_documented_and_implemented {
  ora_secured_setup { "database_backup_procedures_must_be_defined_documented_and_implemented on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
