#
# ora_secured::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user
#
# @summary The `authentication_type='EXTERNAL'` setting determines whether or not a user
# can be authenticated by a remote OS to allow access to the database with full
# authorization. This setting should not be used.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 4.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 4.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 4.3
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 4.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dba_users_authentication_type_is_not_set_to_external_for_any_user` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Integer[8, default]] preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::dba_users_authentication_type_is_not_set_to_external_for_any_user (
  Array              $exclude         = ora_secured::lookup_setting('exclude', []),
  Integer[8,default] $preferred_value = ora_secured::lookup_setting('preferred_value', 12),
) {
  $sid = $title

  ora_secured_setup { "dba_userspassword_is_not_set_to_external_for_any_user on ${sid}":
    ensure => 'present',
  }

  if ora_config::is_root_db($sid) {
      $users_to_check = ora_config::on_sid($facts['ora_users_with_external_password'], $sid) - $exclude
    } else {
      $data = ora_config::on_sid($facts['ora_users_with_external_password'], $sid)
      $users_to_check = $data.filter |$item| { $item !~ /^C##/ }
    }

  $users_to_check.each |$user| {
    $unique = ora_secured::random_id(6)
    $full_name = "Ora_user[${user}@${sid}]password/${unique}"
    resource_value { $full_name:
      value          => ora_config::generated_password($preferred_value),
      allow_create   => true,
      allow_redefine => true,
      warnings       => false,
    }
  }
}
