#
# ora_secured::controls::execute_is_revoked_from_public_on_file_system_packages
#
# @summary As described below, Oracle Database PL/SQL "File System" packages -
# `DBMS_ADVISOR`, `DBMS_LOB` and `UTL_FILE` – provide PL/SQL APIs to access files
# on the servers. The user `PUBLIC` should not be able to execute these packages.
# - The Oracle database `DBMS_ADVISOR` package can be used to write files located
#   on the server where the Oracle instance is installed. The user `PUBLIC` should
#   not be able to execute `DBMS_ADVISOR`.
# - The Oracle database `DBMS_LOB` package provides subprograms that can
#   manipulate and read/write on BLOB's, CLOB's, NCLOB's, BFILE's, and temporary
#   LOB's. The user PUBLIC should not be able to execute `DBMS_LOB`.
# - The Oracle database `UTL_FILE` package can be used to read/write files located
#   on the server where the Oracle instance is installed. The user `PUBLIC` should
#   not be able to execute `UTL_FILE`. 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.1.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.1.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.1.2
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.1.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::execute_is_revoked_from_public_on_file_system_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::execute_is_revoked_from_public_on_file_system_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_file_system_packages` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::execute_is_revoked_from_public_on_file_system_packages (
  Array $list    = ora_secured::lookup_setting('list', undef),
  Array $exclude = ora_secured::lookup_setting('exclude', []),
) {
  $sid = $title
  ora_secured_setup { "execute_is_revoked_from_public_on_filesystem_packages on ${sid}":
    ensure => 'present',
  }
  $packages = $list - $exclude
  $packages.each | $package | {
    ora_secured::internal::revoke_public_grants { "${package}@${sid}": }
  }
}
