#
# ora_secured::controls::have_its_auditing_configured_to_reduce_the_likelihood_of_storage_capacity_being_exceeded
#
# @summary Review the DBMS settings to determine whether audit logging is configured to produce logs consistent with the amount of space allocated for logging.
# If auditing will generate excessive logs so that they may outgrow the space reserved for logging, this is a finding.
# 
# If file-based auditing is in use, check that sufficient space is available to support the file(s). If not, this is a finding
# 
# If standard, table-based auditing is used:  The audit logs are written to a table called AUD$, and if a Virtual Private Database is deployed, we also create a table called FGA_LOG$.  First check the current location of the audit trail tables.
# 
#     CONN / AS SYSDBA
# 
#     SELECT table_name, tablespace_name
#     FROM   dba_tables
#     WHERE  table_name IN ('AUD$', 'FGA_LOG$')
#     ORDER BY table_name;
# 
#     TABLE_NAME                        TABLESPACE_NAME
#   --------------                    ------------------
#     AUD$                                  SYSTEM
#     FGA_LOG$                              SYSTEM
# 
# If the tablespace_name is SYSTEM, the table needs to be relocated to its own tablespace. Ensure that adequate space is allocated to that tablespace.
# 
# If Unified Auditing is used:
# Audit logs are written to tables in the AUDSYS schema. The default tablespace for AUDSYS is USERS. A separate tablespace should be created to contain audit data. Ensure that adequate space is allocated to that tablespace.
# 
# Allocate sufficient disk space for file-based audit.
# 
# Ensure that audit tables are in their own tablespaces and that the tablespaces have enough room for the volume of log data that will be produced.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::have_its_auditing_configured_to_reduce_the_likelihood_of_storage_capacity_being_exceeded: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::have_its_auditing_configured_to_reduce_the_likelihood_of_storage_capacity_being_exceeded::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `have_its_auditing_configured_to_reduce_the_likelihood_of_storage_capacity_being_exceeded` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61613
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::have_its_auditing_configured_to_reduce_the_likelihood_of_storage_capacity_being_exceeded {
  ora_secured_setup { "have_its_auditing_configured_to_reduce_the_likelihood_of_storage_capacity_being_exceeded on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
