#
# ora_secured::controls::lmt_use_of_resources_by_prio_and_not_impede_host_frm_servicing_procs_designated_as_a_higher_prio
#
# @summary Review DBMS settings and documentation to determine if the DBMS restricts resource usage by priority.
# If the DBMS does not restrict resource usage by priority, this is a finding.
# 
# - - - - -
# This capability is available in Oracle at both the user and database level.
# 
# At the user level, we create resource profiles for users of the database.
# 
# Resource Parameters
# SESSIONS_PER_USER - Specify the number of concurrent sessions to which to limit the user.
# CPU_PER_SESSION - Specify the CPU time limit for a session, expressed in hundredths of seconds.
# CPU_PER_CALL - Specify the CPU time limit for a call (a parse, execute, or fetch), expressed in hundredths of seconds.
# CONNECT_TIME - Specify the total elapsed time limit for a session, expressed in minutes.
# IDLE_TIME - Specify the permitted periods of continuous inactive time during a session, expressed in minutes. Long-running queries and other operations are not subject to this limit.
# LOGICAL_READS_PER_SESSION - Specify the permitted number of data blocks read in a session, including blocks read from memory and disk.
# LOGICAL_READS_PER_CALL - Specify the permitted number of data blocks read for a call to process a SQL statement (a parse, execute, or fetch).
# PRIVATE_SGA - Specify the amount of private space a session can allocate in the shared pool of the system global area (SGA).
# COMPOSITE_LIMIT - Specify the total resource cost for a session, expressed in service units.
# 
# To check the resource controls assigned to a user, query the DBA_PROFILES and DBA_USERS tables in the following manner.
# 
# set linesize 121
# col username format a20
# col profile format a20
# col resource_name format a25
# col resource_type format a14
# col limit format a10
# select a.username,
#    a.profile,
#    b.resource_name,
#    b.limit
# from dba_users a,
#      dba_profiles b
# where b.resource_type is not null and
#       a.profile = b.profile order by username;
# 
# The output should look like the output below and display the users and the contents of their profiles.
# 
# USERNAME        PROFILE       RESOURCE NAME      LIMIT
# --------        -------       -------------      -----
# SCOTT           DEFAULT       SESSIONS_PER_USER  UNLIMITED
# SCOTT           DEFAULT       CPU_PER_SESSION    UNLIMITED
# 
# Implement measures to restrict the usage of resources by priority.
# 
# - - - - -
# To implement security at the user level, assign users a profile that limits their resources:
# 
# The user profile, ORA_STIG_PROFILE, has been provided (starting with Oracle 12.1.0.2) to satisfy the STIG requirements pertaining to the profile parameters. Oracle recommends that this profile be customized with any site-specific requirements and assigned to all users where applicable.  Note: It remains necessary to create a customized replacement for the password validation function, ORA12C_STRONG_VERIFY_FUNCTION, if relying on this technique to verify password complexity.
# 
# Example
# 
# $ sqlplus connect as sysdba
# 
# ALTER PROFILE ORA_STIG_PROFILE LIMIT
# SESSIONS_PER_USER    1
# IDLE_TIME           30
# CPU_PER_SESSION    100
# CPU_PER_CALL       100
# CONNECT_TIME       600;
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::lmt_use_of_resources_by_prio_and_not_impede_host_frm_servicing_procs_designated_as_a_higher_prio: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::lmt_use_of_resources_by_prio_and_not_impede_host_frm_servicing_procs_designated_as_a_higher_prio::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `lmt_use_of_resources_by_prio_and_not_impede_host_frm_servicing_procs_designated_as_a_higher_prio` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61819
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::lmt_use_of_resources_by_prio_and_not_impede_host_frm_servicing_procs_designated_as_a_higher_prio {
  ora_secured_setup { "lmt_use_of_resources_by_prio_and_not_impede_host_frm_servicing_procs_designated_as_a_higher_prio on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
