#
# ora_secured::controls::no_public_database_links_exist
#
# @summary Public Database links are used to allow connections between databases.
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 4.6
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 4.6
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 4.6
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 4.6
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::no_public_database_links_exist: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::no_public_database_links_exist::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `no_public_database_links_exist` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::no_public_database_links_exist () {
  $sid = $title
  ora_secured_setup { "no_public_database_links_exist on ${sid}":
    ensure => 'present',
  }

  # lint:ignore:stric_ident
  $sql = @(STATEMENT)
  DECLARE
     l_ddl VARCHAR2(1000);
  BEGIN
    FOR rec IN ( SELECT DB_LINK FROM DBA_DB_LINKS WHERE OWNER = 'PUBLIC') LOOP
      l_ddl := 'drop public database link '|| rec.db_link;
      dbms_output.put_line(l_ddl);
      EXECUTE IMMEDIATE (l_ddl);
      END LOOP;
  END;
  /
  | STATEMENT
  # lint:endignore:stric_ident

ora_exec { "delete_public_database_links@${sid}":
    onlyif    => "SELECT DB_LINK, HOST FROM DBA_DB_LINKS WHERE OWNER = 'PUBLIC'",
    statement => $sql,
  }
}
