#
# ora_secured::controls::o7_dictionary_accessibility_is_set_to_false
#
# @summary The `O7_dictionary_accessibility` setting is a database initialization parameter
# that allows/disallows access to objects with the ANY privileges (`SELECT ANY TABLE`, `DELETE ANY TABLE`, `EXECUTE ANY PROCEDURE`, etc.). This functionality
# was created for the ease of migration from Oracle 7 databases to later versions.
# The setting should have a value of FALSE.
# 
# Note: The O7_dictionary_accessibility parameter has been deprecated in 12.2 and
# higher versions.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::o7_dictionary_accessibility_is_set_to_false: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::o7_dictionary_accessibility_is_set_to_false::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `o7_dictionary_accessibility_is_set_to_false` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::o7_dictionary_accessibility_is_set_to_false () {
  $sid = $title
  $unique = ora_secured::random_id(6)
  $oracle_version = ora_config::on_sid($facts['ora_version'], $sid)[0]
  #
  # Skip until Oracle version known
  #
  if $oracle_version != undef {
    $major_oracle_version = split($oracle_version, '\.')[0]
    if Integer($major_oracle_version) < 19 {
      ora_secured_setup { "o7_dictionary_accessibility_is_set_to_false on ${sid}":
        ensure => 'present',
      }
      -> ora_secured::internal::parameter { "O7_DICTIONARY_ACCESSIBILITY@${sid}@${unique}":
        value => 'FALSE',
      }
    } else {
      alert("On Oracle 19 and higher O7_DICTIONARY_ACCESSIBILITY initialization parameter has been made obsolete. Rule skipped for ${title}")
    }
  }
}
