#
# ora_secured::controls::password_grace_time_is_less_than_or_equal_to_5
#
# @summary The `PASSWORD_GRACE_TIME` setting determines how many days can pass after the
# user's password expires before the user's login capability is automatically
# locked out. The suggested value for this is five days or less.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 3.6
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 3.6
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 3.6
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 3.6
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::password_grace_time_is_less_than_or_equal_to_5: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::password_grace_time_is_less_than_or_equal_to_5::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `password_grace_time_is_less_than_or_equal_to_5` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
# @param [Array] only
#    The list of object to only apply the control to.
#
# @param [Integer[0, 5]] preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::password_grace_time_is_less_than_or_equal_to_5 (
  Array        $exclude          = ora_secured::lookup_setting('exclude', []),
  Array        $only             = ora_secured::lookup_setting('only', []),
  Integer[0,5]  $preferred_value = ora_secured::lookup_setting('preferred_value', 5),
) {
  $sid = $title
  ora_secured_setup { "password_grace_time_is_less_than_or_equal_to_5 on ${sid}":
    ensure => 'present',
  }
  -> ora_secured::internal::profile_setting { "password_grace_time@${sid}":
    value   => $preferred_value,
    exclude => $exclude,
    only    => $only,
  }
}
