#
# ora_secured::controls::protect_audit_information_from_any_type_of_unauthorized_access
#
# @summary Review locations of audit logs, both internal to the database and database audit logs located at the operating system-level.
# Verify there are appropriate controls and permissions to protect the audit information from unauthorized access.
# 
# If appropriate controls and permissions do not exist, this is a finding.
# 
# - - - - -
# If Standard Auditing is used:
# DBA_TAB_PRIVS describes all object grants in the database.  Check to see who has permissions on the AUD$ table.  
# 
# Related View
# 
# DBA_TAB_PRIVS describes the object grants for which the current user is the object owner, grantor, or grantee.
# Column      Datatype        NULL        Description  
# GRANTEE     VARCHAR2(30)  NOT NULL   Name of the user to whom access was granted
# OWNER       VARCHAR2(30)  NOT NULL   Owner of the object
# TABLE_NAME  VARCHAR2(30)  NOT NULL   Name of the object
# GRANTOR     VARCHAR2(30)  NOT NULL   Name of the user who performed the grant
# PRIVILEGE   VARCHAR2(40)  NOT NULL   Privilege on the object
# GRANTABLE   VARCHAR2(3)   Indicates whether the privilege was granted with the GRANT OPTION (YES) or not (NO)
# HIERARCHY   VARCHAR2(3)   Indicates whether the privilege was granted with the HIERARCHY OPTION (YES) or not (NO)
# COMMON      VARCHAR2(3)
# TYPE        VARCHAR2(24)
# 
# sqlplus connect as sysdba;
# 
# SQL>  SELECT GRANTEE, TABLE_NAME, PRIVILEGE
#       FROM DBA_TAB_PRIVS where table_name = 'AUD$';
# 
# If Unified Auditing is used:
# DBA_TAB_PRIVS describes all object grants in the database.  Check to see who has permissions on the AUDSYS tables.
# 
# Related View
# 
# DBA_TAB_PRIVS describes the object grants for which the current user is the object owner, grantor, or grantee.
# Column      Datatype        NULL       Description
# GRANTEE     VARCHAR2(30)    NOT NULL   Name of the user to whom access was granted
# OWNER       VARCHAR2(30)    NOT NULL   Owner of the object
# TABLE_NAME  VARCHAR2(30)    NOT NULL   Name of the object
# GRANTOR     VARCHAR2(30)    NOT NULL   Name of the user who performed the grant
# PRIVILEGE   VARCHAR2(40)    NOT NULL   Privilege on the object
# GRANTABLE   VARCHAR2(3)     Indicates whether the privilege was granted with the GRANT OPTION (YES) or not (NO)
# HIERARCHY   VARCHAR2(3)     Indicates whether the privilege was granted with the HIERARCHY OPTION (YES) or not (NO)
# COMMON      VARCHAR2(3)
# TYPE        VARCHAR2(24)
# 
# sqlplus connect as sysdba;
# 
# SQL>  SELECT GRANTEE, TABLE_NAME, PRIVILEGE
#       FROM DBA_TAB_PRIVS where owner='AUDSYS';
# 
# Add controls and modify permissions to protect database audit log data from unauthorized access, whether stored in the database itself or at the OS level.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::protect_audit_information_from_any_type_of_unauthorized_access: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::protect_audit_information_from_any_type_of_unauthorized_access::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `protect_audit_information_from_any_type_of_unauthorized_access` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61653
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::protect_audit_information_from_any_type_of_unauthorized_access {
  ora_secured_setup { "protect_audit_information_from_any_type_of_unauthorized_access on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
