#
# ora_secured::controls::sec_protocol_error_trace_action_is_set_to_log
#
# @summary The `SEC_PROTOCOL_ERROR_TRACE_ACTION` setting determines the Oracle's server's
# logging response level to bad/malformed packets received from the client by
# generating `ALERT`, `LOG`, or `TRACE` levels of detail in the log files. This
# setting should have a value of `LOG` unless the organization has a compelling
# reason to use a different value because `LOG` should cause the necessary
# information to be logged. Setting the value as `TRACE` can generate an enormous
# amount of log output and should be reserved for debugging only.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.14
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.13
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.12
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.2.12
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::sec_protocol_error_trace_action_is_set_to_log: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::sec_protocol_error_trace_action_is_set_to_log::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sec_protocol_error_trace_action_is_set_to_log` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::sec_protocol_error_trace_action_is_set_to_log () {
  $sid = $title
  $unique = ora_secured::random_id(6)

  ora_secured_setup { "sec_protocol_error_trace_action_is_set_to_log on ${sid}":
    ensure => 'present',
  }
  -> ora_secured::internal::parameter { "SEC_PROTOCOL_ERROR_TRACE_ACTION@${sid}@${unique}":
    value => 'LOG',
  }
}
