#
# ora_secured::controls::use_of_external_executables_must_be_authorized
#
# @summary Review the database for definitions of application executable objects stored external to the database.
# Determine if there are methods to disable use or access, or to remove definitions for external executable objects.
# 
# Verify any application executable objects listed are authorized by the ISSO.
# 
# If any are not, this is a finding.
# If the external executables or libraries are owned by ''SYS'' this is not a finding.
# 
# 
# To check for external procedures, execute the following query which will provide the libraries containing external procedures, the owners of those libraries, users that have been granted access to those libraries, and the privileges they have been granted. If there are owners other than the owners that Oracle provides, then there may be executable objects stored either in the database or external to the database that are called by objects in the database. Check to see that those owners are authorized to access those libraries. If there are users that have been granted access to libraries provided by Oracle, check to see that they are authorized to access those libraries.
# 
# (connect as sysdba)
# set linesize 130
# column library_name format a25
# column name format a15
# column owner format a15
# column grantee format a15
# column privilege format a15
# select library_name,owner, '' grantee, '' privilege
# from dba_libraries where file_spec is not null
# minus
# (
# select library_name,o.name owner, '' grantee, '' privilege
# from dba_libraries l,
# sys.user$ o,
# sys.user$ ge,
# sys.obj$ obj,
# sys.objauth$ oa
# where l.owner=o.name
# and obj.owner#=o.user#
# and obj.name=l.library_name
# and oa.obj#=obj.obj#
# and ge.user#=oa.grantee#
# and l.file_spec is not null
# )
# union all
# select library_name,o.name owner, --obj.obj#,oa.privilege#,
# ge.name grantee,
# tpm.name privilege
# from dba_libraries l,
# sys.user$ o,
# sys.user$ ge,
# sys.obj$ obj,
# sys.objauth$ oa,
# sys.table_privilege_map tpm
# where l.owner=o.name
# and obj.owner#=o.user#
# and obj.name=l.library_name
# and oa.obj#=obj.obj#
# and ge.user#=oa.grantee#
# and tpm.privilege=oa.privilege#
# and l.file_spec is not null
# /
# 
# 
# Disable use of or remove any external application executable object definitions that are not authorized.
# 
# Revoke privileges granted to users that are not authorized access to external applications.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::controls::use_of_external_executables_must_be_authorized: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::controls::use_of_external_executables_must_be_authorized::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `use_of_external_executables_must_be_authorized` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V1](/docs/ora_secured/stig/db12c_V1.html) - id V-61683
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::controls::use_of_external_executables_must_be_authorized {
  ora_secured_setup { "use_of_external_executables_must_be_authorized on ${title}":
    ensure => 'present',
  }

  alert('Specified STIG control is not yet automatically enforced.')
}
