#
# ora_secured::ensure_cis
#
# @summary defined type `ora_secured::ensure_cis`
# Apply **all** Oracle database CIS control to the specified database
# 
# Here is an example showing how to enable the CIS bencgmark for your database.:
# 
# ``` puppet
# ora_secured::ensure_cis { 'DBNAME':
#   product_version => 'db19c',
#   doc_version     => 'V1.0.0',
# }
# ```
# 
# When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`. If you also don't specify a `product_version`, Puppet will detect the version of Oracle running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Oracle version is. In that case, the ora_secured defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Oracle for specified sid is available.
# 
# When you want to skip certain controls, you can use the `skip_list`.
# 
# ``` puppet
# ora_secured::ensure_cis { 'DBNAME':
#   product_version => 'db19c',
#   doc_version     => 'V1.0.0',
#   skip_list       => [
#     'alter_database_link_action_audit_is_enabled',
#     'alter_role_action_audit_is_enabled',
#   ]
# }
# ```
# 
# When you have multiple database on your system and want to use the same database version and CIS document version, you can do this:
# 
# ``` puppet
# ora_secured::Ensure_cis {
#   product_version => 'db19c',
#   doc_version     => 'V1.0.0',
#   skip_list       => [
#     'alter_database_link_action_audit_is_enabled',
#     'alter_role_action_audit_is_enabled',
#   ]
# }
# 
# ora_secured::ensure_cis {'DB1':}
# ora_secured::ensure_cis {'DB2':}
# ```
#
# @param title
#    The SID to apply the control to.
#    The CIS benchmark need an SID to apply the controls to. Here is a simple example:
#    ``` puppet
#    ora_secured { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the controls to.
#
# @param [Optional[String[1]]] product_version
#    The database version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) database version to your database.
#    If you also don't specify a `product_version`, Puppet will detect the version of Oracle running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Oracle version is. In that case, the ora_secured defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Oracle for specified sid is available.
#
# @param [Optional[String[1]]] doc_version
#    The version of the CIS benchmark you want to apply to your database.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`.
#
# @param all_controls
#    This is an internal parameter.
#    This is the Hash containing all paragraphs from the selected CIS benchmark.
#
# @param nonpdb_controls
#    This is an internal parameter.
#    It contains all of the controls that don't run on a pluggable database.
#
# @param [Array] skip_list
#    This is the list of controls that you want to skip.
#    By default this vale is empty, meaning `ora_secured` will apply **ALL** controls. You must specifiy the name of the control. Here is an example on how to do this:
#        ora_secured { 'MYDB':
#          product_version  => 'db19c',
#          doc_version => 'V1.0.0',
#          skip_list   => [
#            'alter_database_link_action_audit_is_enabled',
#            'alter_role_action_audit_is_enabled',
#          ]
#        }
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::ensure_cis (
  Optional[String[1]]                         $product_version = ora_secured::default_product_version($title),
  Optional[String[1]]                         $doc_version     = ora_secured::default_doc_version($product_version, 'cis'),
  Optional[String[1]]                         $profile         = ora_secured::lookup_setting('profile', 'level-1-rdbms-traditional'),
  Array                                       $skip_list       = ora_secured::lookup_setting('skip_list', []),
  Optional[String[1]]                         $use_schedule    = ora_secured::lookup_setting('use_schedule', undef),
  Enum['skip','validate', 'enforce', 'both']  $operation       = ora_secured::lookup_setting('operation', 'enforce'),
) {
  easy_type::secure::ensure_benchmark { $title:
    benchmark       => 'cis',
    product_version => $product_version,
    doc_version     => $doc_version,
    profile         => $profile,
    skip_list       => $skip_list,
    use_schedule    => $use_schedule,
    operation       => $operation,
  }
}
