#
# ora_secured::validators::all_audit_option_on_sys_aud_is_enabled
#
# @summary The logging of attempts to alter the audit trail in the `SYS.
# AUD$` table (open
# for read/update/delete/view) will provide a record of any activities that may
# indicate unauthorized attempts to access the audit trail. Enabling the audit
# option will cause these activities to be audited.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.1.14
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.1.14
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.1.14
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 6.1.14
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::all_audit_option_on_sys_aud_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::all_audit_option_on_sys_aud_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_audit_option_on_sys_aud_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::all_audit_option_on_sys_aud_is_enabled (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT *
      FROM CDB_OBJ_AUDIT_OPTS
      WHERE OBJECT_NAME = 'AUD$'
        AND ALT = 'A/A'
        AND AUD = 'A/A'
        AND COM = 'A/A'
        AND DEL = 'A/A'
        AND GRA = 'A/A'
        AND IND = 'A/A'
        AND INS = 'A/A'
        AND LOC = 'A/A'
        AND REN = 'A/A'
        AND SEL = 'A/A'
        AND UPD = 'A/A'
        AND FBK = 'A/A'
    |-QUERY

  ora_secured_setup { "all_audit_option_on_sys_aud_is_enabled validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "AUDIT ALL should be enabled on AUD$ on ${title}":
    check                   => $query,
    expected_number_of_rows => 1,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "AUDIT ALL should be enabled on AUD$, but it's NOT",
  }
}
