#
# ora_secured::validators::all_default_passwords_are_changed
#
# @summary Default passwords should not be used by Oracle database users.
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 4.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 4.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 4.1
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 4.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::all_default_passwords_are_changed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::all_default_passwords_are_changed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_default_passwords_are_changed` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude
#    The objects to exclude from the control actions.
#
# @param password_length
#    The password length to use when generating new passwords.
#    Beware that you **must** set this to ??
#    The deafult value is 12.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::all_default_passwords_are_changed (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT DISTINCT A.USERNAME,
           DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_USERS_WITH_DEFPWD A
          , CDB_USERS C
      WHERE A.USERNAME = C.USERNAME
        AND C.ACCOUNT_STATUS = 'OPEN'
    |-QUERY

  ora_secured_setup { "all_default_passwords_are_changed validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "All default passwords should be changed on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => 'All default passwords should be changed but they are NOT',
  }
}
