#
# ora_secured::validators::all_is_revoked_from_unauthorized_grantee_on_aud
#
# @summary The Oracle database `SYS.
# AUD$` table contains all the audit records for the
# database of the non-Data Manipulation Language (DML) events, such as `ALTER`,
# `DROP`, and `CREATE`, and so forth. (DML changes need trigger-based audit events
# to record data alterations.) Unauthorized grantees should not have full access
# to that table.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.3.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.3.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.3.1
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.3.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::all_is_revoked_from_unauthorized_grantee_on_aud: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::all_is_revoked_from_unauthorized_grantee_on_aud::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_is_revoked_from_unauthorized_grantee_on_aud` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::all_is_revoked_from_unauthorized_grantee_on_aud (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT GRANTEE
         , PRIVILEGE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_TAB_PRIVS A
     WHERE TABLE_NAME = 'AUD$'
       AND OWNER = 'SYS'
    |-QUERY

  ora_secured_setup { "all_is_revoked_from_unauthorized_grantee_on_aud validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "No unprivileged users have access to AUD$ on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Unprivileged users should not have access to 'AUD\$', but SOME USERS HAVE IT",
  }
}
