#
# ora_secured::validators::all_is_revoked_on_sensitive_tables
#
# @summary The Oracle database tables listed below may contain sensitive information, and
# should not be accessible to unauthorized users.
# 
# - `USER$`, `USER_HISTORY$`, `XS$VERIFIERS` and `DEFAULT_PWD$` may contain
#   password hashes.
# - `CDB_LOCAL_ADMINAUTH$` and `PDB_SYNC$` may contain DDLs.
# - `LINK$` and `SCHEDULER$_CREDENTIA`L may contain encrypted passwords.
# - `ENC$` may contains encryption keys.
# - `HISTGRM$` and `HIST_HEAD$` may contain sensitive data.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.3.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.3.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.3.3
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.3.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::all_is_revoked_on_sensitive_tables: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::all_is_revoked_on_sensitive_tables::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `all_is_revoked_on_sensitive_tables` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::all_is_revoked_on_sensitive_tables (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT TABLE_NAME
         , PRIVILEGE
         , GRANTEE,DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                                    1,(SELECT NAME FROM V$DATABASE),
                                      (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_TAB_PRIVS A
     WHERE TABLE_NAME IN ('CDB_LOCAL_ADMINAUTH$'
                         ,'DEFAULT_PWD$'
                         ,'ENC$'
                         ,'HISTGRM$'
                         ,'HIST_HEAD$'
                         ,'LINK$'
                         ,'PDB_SYNC$'
                         ,'SCHEDULER$_CREDENTIAL'
                         ,'USER$'
                         ,'USER_HISTORY$'
                         ,'XS$VERIFIERS')
       AND OWNER = 'SYS'
       AND GRANTEE NOT IN (SELECT USERNAME FROM DBA_USERS WHERE ORACLE_MAINTAINED = 'Y')
       AND GRANTEE NOT IN (SELECT ROLE FROM DBA_ROLES WHERE ORACLE_MAINTAINED = 'Y')
     ORDER BY CON_ID, TABLE_NAME
    |-QUERY

  ora_secured_setup { "all_is_revoked_on_sensitive_tables validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "No unprivileged users have access to sensitive tables on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => 'Unprivileged users should not have access to sensitive tables, but SOME USERS HAVE IT',
  }
}
