#
# ora_secured::validators::alter_trigger_action_audit_is_enabled
#
# @summary Oracle database triggers are executed automatically when specified conditions on
# the underlying objects occur. Trigger bodies contain the code, quite often to
# perform data validation, ensure data integrity/security or enforce critical
# constraints on allowable actions on data. Enabling this unified audit causes
# logging of all `ALTER TRIGGER` statements, whether successful or unsuccessful,
# issued by the users regardless of the privileges held by the users to issue such
# statements.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.2.25
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.2.25
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.2.25
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 6.2.25
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::alter_trigger_action_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::alter_trigger_action_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `alter_trigger_action_audit_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::alter_trigger_action_audit_is_enabled (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    WITH
      CIS_AUDIT(AUDIT_OPTION) AS
        (
          SELECT * FROM TABLE(
                                DBMSOUTPUT_LINESARRAY( 'ALTER TRIGGER' )
                             )
        ),
      AUDIT_ENABLED AS
        (
          SELECT DISTINCT AUDIT_OPTION
            FROM AUDIT_UNIFIED_POLICIES AUD
           WHERE AUD.AUDIT_OPTION IN ( 'ALTER TRIGGER' )
             AND AUD.AUDIT_OPTION_TYPE = 'STANDARD ACTION'
             AND EXISTS (SELECT *
                           FROM AUDIT_UNIFIED_ENABLED_POLICIES ENABLED
                          WHERE ENABLED.SUCCESS = 'YES'
                            AND ENABLED.FAILURE = 'YES'
                            AND ENABLED.ENABLED_OPTION = 'BY USER'
                            AND ENABLED.ENTITY_NAME = 'ALL USERS'
                            AND ENABLED.POLICY_NAME = AUD.POLICY_NAME)
        )
      SELECT C.AUDIT_OPTION
        FROM CIS_AUDIT C
               LEFT JOIN AUDIT_ENABLED E
          ON C.AUDIT_OPTION = E.AUDIT_OPTION
       WHERE E.AUDIT_OPTION IS NULL
    |-QUERY

  ora_secured_setup { "alter_trigger_action_audit_is_enabled validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "Auditing is enabled for ALTER TRIGGER action on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Auditing should be enabled for ALTER TRIGGER action, but it's NOT",
  }
}
