#
# ora_secured::validators::audit_admin_is_revoked_from_unauthorized_grantee
#
# @summary The Oracle database `AUDIT_ADMIN` enables you to create unified and fine-grained audit policies, use the `AUDIT` and `NOAUDIT` SQL statements, view audit data, and manage the audit trail administration.
# Grant this role only to trusted users. Unauthorized grantees should not have this role.
# 
# ## Rationale
# 
# Assignment of the `AUDIT_ADMIN` role to an ordinary user can provide a great number of unnecessary privileges to that user and open the door to data breaches, integrity violations, and denial-of-service conditions.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.3.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::audit_admin_is_revoked_from_unauthorized_grantee: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::audit_admin_is_revoked_from_unauthorized_grantee::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audit_admin_is_revoked_from_unauthorized_grantee` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All validators need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::validators::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param [Array] exclude_users
#    The users to exclude from the control actions.
#
# @param [Array] exclude_roles
#    The roles to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::audit_admin_is_revoked_from_unauthorized_grantee (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT 'GRANT' AS PATH
         , GRANTEE
         , GRANTED_ROLE,
           DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_ROLE_PRIVS A
     WHERE GRANTED_ROLE = 'AUDIT_ADMIN'
       AND GRANTEE NOT IN ('SYS', 'SYSTEM')
     UNION
    SELECT 'PROXY'
         , PROXY || '-' || CLIENT
         , 'AUDIT_ADMIN'
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_PROXIES A
     WHERE CLIENT IN (SELECT GRANTEE
                        FROM CDB_ROLE_PRIVS B
                       WHERE GRANTED_ROLE = 'AUDIT_ADMIN'
                         AND A.CON_ID = B.CON_ID)
    |-QUERY

  ora_secured_setup { "audit_admin_is_revoked_from_unauthorized_grantee validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'AUDIT_ADMIN' is revoked from unprivileged users on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Unprivileged users should not have 'AUDIT_ADMIN' privileges, but SOME USERS HAVE IT",
  }
}
