#
# ora_secured::validators::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended
#
# @summary The `audit_trail` setting determines whether or not Oracle's basic audit features
# are enabled. It can be set to "Operating System"(OS); `DB; DB,EXTENDED`; `XML`; or
# `XML,EXTENDED`. The value should be set according to the needs of the
# organization.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.2
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.2.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT UPPER(REPLACE(VALUE, ',', ';')) AS VALUE
      FROM V$SYSTEM_PARAMETER
     WHERE UPPER(NAME) = 'AUDIT_TRAIL'
       AND (
                VALUE = 'DB'
             OR VALUE = 'DB, EXTENDED'
             OR VALUE = 'EXTENDED, DB'
             OR VALUE = 'OS'
             OR VALUE = 'XML, EXTENDED'
             OR VALUE = 'EXTENDED, XML'
           )
    |-QUERY

  ora_secured_setup { "audit_trail_is_set_to_db_xml_os_dbextended_or_xmlextended validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'AUDIT_TRAIL' should be set to 'DB', 'DB, EXTENDED', 'OS', 'XML' or 'XML, EXTENDED' on ${title}":
    check                   => $query,
    expected_number_of_rows => 1,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,                                                                                      # $skip, # Remove the true after the chack has been filled in
    control                 => easy_type::current_control(),
    fail_message            => "'AUDIT_TRAIL' should be set to 'DB', 'DB, EXTENDED', 'OS', 'XML' or 'XML, EXTENDED', but it's NOT",
  }
}
