#
# ora_secured::validators::audsys_aud_unified_access_audit_is_enabled
#
# @summary The `AUDSYS.
# AUD$UNIFIED` holds audit trail records generated by the database.
# Enabling this audit action causes logging of all access attempts to the
# `AUDSYS.AUD$UNIFIED`, whether successful or unsuccessful, regardless of the
# privileges held by the users to issue such statements.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 6.2.19
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 6.2.19
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 6.2.19
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 6.2.19
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::audsys_aud_unified_access_audit_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::audsys_aud_unified_access_audit_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audsys_aud_unified_access_audit_is_enabled` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::audsys_aud_unified_access_audit_is_enabled (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    WITH
      CIS_AUDIT(AUDIT_OPTION) AS
        (
          SELECT * FROM TABLE( DBMSOUTPUT_LINESARRAY( 'AUD$UNIFIED' ) )
        ),
      AUDIT_ENABLED AS
        (
          SELECT DISTINCT OBJECT_NAME
            FROM AUDIT_UNIFIED_POLICIES AUD
           WHERE AUD.AUDIT_OPTION IN ( 'ALL' )
             AND AUD.AUDIT_OPTION_TYPE = 'OBJECT ACTION'
             AND AUD.OBJECT_SCHEMA = 'AUDSYS'
             AND AUD.OBJECT_NAME = 'AUD$UNIFIED'
             AND EXISTS (
                          SELECT *
                            FROM AUDIT_UNIFIED_ENABLED_POLICIES ENABLED
                           WHERE ENABLED.SUCCESS = 'YES'
                             AND ENABLED.FAILURE = 'YES'
                             AND ENABLED.ENABLED_OPTION = 'BY USER'
                             AND ENABLED.ENTITY_NAME = 'ALL USERS'
                             AND ENABLED.POLICY_NAME = AUD.POLICY_NAME
                        )
        )
      SELECT C.AUDIT_OPTION
        FROM CIS_AUDIT C
               LEFT JOIN AUDIT_ENABLED E
          ON C.AUDIT_OPTION = E.OBJECT_NAME
        WHERE E.OBJECT_NAME IS NULL
    |-QUERY

  ora_secured_setup { "audsys_aud_unified_access_audit_is_enabled validation on ${title}":
    ensure => present,
  }
  -> validation { "Access auditing is enabled for 'AUDSYS.AUD\$UNIFIED' on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Access auditing on 'AUDSYS.AUD\$UNIFIED' should be enabled, but it's NOT",
  }
}
