#
# ora_secured::validators::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes
#
# @summary The Oracle database `WITH_ADMIN` privilege allows the designated user to grant
# another user the same privileges. Unauthorized grantees should not have that
# privilege.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.2.2
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.2.2
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.2.2
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.2.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT GRANTEE
         , PRIVILEGE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_SYS_PRIVS A
     WHERE ADMIN_OPTION = 'YES'
       AND GRANTEE NOT IN (SELECT USERNAME FROM CDB_USERS WHERE ORACLE_MAINTAINED = 'Y')
       AND GRANTEE NOT IN (SELECT ROLE FROM CDB_ROLES WHERE ORACLE_MAINTAINED = 'Y')
    |-QUERY

  ora_secured_setup { "dba_sys_privs_is_revoked_from_unauthorized_grantee_with_admin_option_set_to_yes validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'WITH ADMIN OPTION' on 'SYSTEM PRIVILEGES' is not granted to unprivileged users on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Unprivileged users should not have 'SYSTEM PRIVILEGES' 'WITH ADMIN OPTION', but SOME USERS HAVE IT",
  }
}
