#
# ora_secured::validators::encryption_server_is_set_to_required
#
# @summary The setting sqlnet.
# encryption_server=required requires that the connections to the database are encrypted through Oracle SQL*Net native encryption. The encryption setting implements data-in-transit encryption for the Oracle database connections. This setting is configured in the sqlnet.ora file on the database server.
# 
# ## Rationale
# 
# Without this setting, malicious users could potentially eavesdrop on the database connections, compromising the confidentiality of the data.
# 
# ## Impact
# 
# encryption_server=required could reject/deny connection requests from those database users who don’t support the Oracle native network encryption.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::encryption_server_is_set_to_required: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::encryption_server_is_set_to_required::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `encryption_server_is_set_to_required` to the array value `ora_secured::skip_list` in your hiera data.  
# 
# 
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.3.1
#
# @param title
#    The SID to apply the control to.
#    All validators need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::validators::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::encryption_server_is_set_to_on (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  ora_secured_setup { "encryption_server_is_set_to_on validation on ${title}":
    ensure => present,
  }

  $installed_homes = $facts['ora_install_homes']
  $installed_homes['running_processes'].keys.each |$oracle_home| {
    unless $installed_homes.dig('running_processes', $oracle_home, 'listeners').length == 0 {
      $installed_homes['running_processes'][$oracle_home]['listeners'].each |$listener| {
        # lint:ignore:double_quoted_strings
        validation { "ENCRYPTION_SERVER is set to ON in sqlnet.ora in home ${oracle_home} for ${title}":
          check           => "grep -i \"^ENCRYPTION_SERVER.*=.*ON\" ${oracle_home}/network/admin/sqlnet.ora",
          path            => ['/bin'],
          expected_output => Regexp("(?i-mx:^ENCRYPTION_SERVER.*=.*ON)"),
          report_as       => $report_as,
          skip            => $skip,
          control         => easy_type::current_control(),
          fail_message    => "ENCRYPTION_SERVER should be set to ON in sqlnet.ora in ${oracle_home}, but it's NOT",
          require         => Ora_secured_setup["encryption_server_is_set_to_on validation on ${title}"],
        }
        # lint:endignore:double_quoted_strings
      }
    }
  }
}
