#
# ora_secured::validators::execute_is_not_granted_to_public_on_non_default_packages
#
# @summary The packages described in this control are not granted to `PUBLIC` by default
# ("Non-default" packages). These packages should not be granted to `PUBLIC`.
# - The Oracle database `DBMS_BACKUP_RESTORE` package is used for applying PL/SQL
#   commands to the native RMAN sequences.
# - The Oracle database `DBMS_FILE_TRANSFER` package allows a user to transfer
#   files from one database server to another.
# - The Oracle database `DBMS_SYS_SQL`,`DBMS_REPCAT_SQL_UTL`, `INITJVMAUX`,
#   `DBMS_AQADM_SYS`, `DBMS_STREAMS_RPC`, `DBMS_PRVTAQIM`, `LTADM` and `DBMS_IJOB`
#   packages are shipped as undocumented.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.2.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.2.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.2.1
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.2.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::execute_is_not_granted_to_public_on_non_default_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::execute_is_not_granted_to_public_on_non_default_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_not_granted_to_public_on_non_default_packages` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::execute_is_not_granted_to_public_on_non_default_packages (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT TABLE_NAME
         , PRIVILEGE
         , GRANTEE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_TAB_PRIVS A
     WHERE GRANTEE = 'PUBLIC'
       AND PRIVILEGE = 'EXECUTE'
       AND TABLE_NAME IN ( 'DBMS_BACKUP_RESTORE'
                         , 'DBMS_FILE_TRANSFER'
                         , 'DBMS_SYS_SQL'
                         , 'DBMS_REPCAT_SQL_UTL'
                         , 'INITJVMAUX'
                         , 'DBMS_AQADM_SYS'
                         , 'DBMS_STREAMS_RPC'
                         , 'DBMS_PRVTAQIM'
                         , 'LTADM'
                         , 'DBMS_IJOB'
                         , 'DBMS_PDB_EXEC_SQL'
                         )
     ORDER BY CON_ID, TABLE_NAME
    |-QUERY

  ora_secured_setup { "execute_is_not_granted_to_public_on_non_default_packages validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'EXECUTE' is revoked from PUBLIC on non-default packages on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'EXECUTE' should be revoked from PUBLIC on non-default packages, but it's NOT",
  }
}
