#
# ora_secured::validators::execute_is_revoked_from_public_on_encryption_packages
#
# @summary As described below, Oracle Database PL/SQL "Encryption" packages -
# `DBMS_CRYPTO`, `DBMS_OBFUSCATION_TOOLKIT` and `DBMS_RANDOM` – provide PL/SQL
# APIs to perform functions related to cryptography. The `PUBLIC` should not be
# able to execute these packages.
# - The `DBMS_CRYPTO` settings provide a toolset that determines the strength of
#   the encryption algorithm used to encrypt application data and is part of the
#   `SYS` schema. The `DES` (56-bit key), 3`DES` (168-bit key), `3DES-2KEY`
#   (112-bit key), `AES` (128/192/256-bit keys), and `RC4` are available.
# - The `DBMS_OBFUSCATION_TOOLKIT` provides one of the tools that determine the
#   strength of the encryption algorithm used to encrypt application data and is
#   part of the `SYS` schema. The DES (56-bit key) and 3DES (168-bit key) are the
#   only two types available.
# - The Oracle database `DBMS_RANDOM` package is used for generating random
#   numbers but should not be used for cryptographic purposes.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.1.3
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.1.3
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.1.3
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.1.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::execute_is_revoked_from_public_on_encryption_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::execute_is_revoked_from_public_on_encryption_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_encryption_packages` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::execute_is_revoked_from_public_on_encryption_packages (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT TABLE_NAME
         , PRIVILEGE
         , GRANTEE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_TAB_PRIVS A
     WHERE GRANTEE = 'PUBLIC'
       AND PRIVILEGE = 'EXECUTE'
       AND TABLE_NAME IN ( 'DBMS_CRYPTO'
                         , 'DBMS_OBFUSCATION_TOOLKIT'
                         , 'DBMS_RANDOM'
                         )
     ORDER BY CON_ID, TABLE_NAME
    |-QUERY

  ora_secured_setup { "execute_is_revoked_from_public_on_encryption_packages validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'EXECUTE' is revoked from PUBLIC on 'encryption' packages on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'EXECUTE' should be revoked from PUBLIC on 'encryption' packages, but it's NOT",
  }
}
