#
# ora_secured::validators::execute_is_revoked_from_public_on_network_packages
#
# @summary As described below, Oracle Database PL/SQL "Network" packages - `DBMS_LDAP`,
# `UTL_INADDR`, `UTL_TCP`, `UTL_MAIL`, `UTL_SMTP`, `UTL_DBWS`, `UTL_ORAMTS`,
# `UTL_HTTP` and type `HTTPURITYPE` – provide PL/SQL APIs to interact or access
# remote servers. The `PUBLIC` should not be able to execute these packages.
# 
# - The Oracle database `DBMS_LDAP` package contains functions and procedures that
#   enable programmers to access data from LDAP servers.
# - The Oracle database `UTL_INADDR` package provides an API to retrieve host
#   names and IP addresses of local and remote hosts.
# - The Oracle database `UTL_TCP` package can be used to read/write file to TCP
#   sockets on the server where the Oracle instance is installed.
# - The Oracle database `UTL_MAIL` package can be used to send email from the
#   server where the Oracle instance is installed.
# - The Oracle database `UTL_SMTP` package can be used to send email from the
#   server where the Oracle instance is installed. The user `PUBLIC` should not be
#   able to execute `UTL_SMTP`.
# - The Oracle database `UTL_DBWS` package can be used to read/write file to
#   web-based applications on the server where the Oracle instance is installed.
#   This package is not automatically installed for security reasons.
# - The Oracle database `UTL_ORAMTS` package can be used to perform HTTP requests.
#   This could be used to send information to the outside. 84 | P a g e
# - The Oracle database `UTL_HTTP` package can be used to perform HTTP requests.
#   This could be used to send information to the outside.
# - The Oracle database `HTTPURITYPE` object type can be used to perform HTTP
#   requests.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.1.1
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.1.1
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.1.1
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.1.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::execute_is_revoked_from_public_on_network_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::execute_is_revoked_from_public_on_network_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_network_packages` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::execute_is_revoked_from_public_on_network_packages (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT TABLE_NAME
         , PRIVILEGE
         , GRANTEE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_TAB_PRIVS A
     WHERE GRANTEE = 'PUBLIC'
       AND PRIVILEGE = 'EXECUTE'
       AND TABLE_NAME IN ( 'DBMS_LDAP'
                         , 'UTL_INADDR'
                         , 'UTL_TCP'
                         , 'UTL_MAIL'
                         , 'UTL_SMTP'
                         , 'UTL_DBWS'
                         , 'UTL_ORAMTS'
                         , 'UTL_HTTP'
                         , 'HTTPURITYPE'
                         )
     ORDER BY CON_ID, TABLE_NAME
    |-QUERY

  ora_secured_setup { "execute_is_revoked_from_public_on_network_packages validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'EXECUTE' is revoked from PUBLIC on 'network' packages on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'EXECUTE' should be revoked from PUBLIC on 'network' packages, but it's NOT",
  }
}
