#
# ora_secured::validators::execute_is_revoked_from_public_on_sql_injection_helper_packages
#
# @summary As described below, Oracle Database PL/SQL "SQL Injection Helper Packages"
# packages - `DBMS_SQL`, `DBMS_XMLGEN`, `DBMS_XMLQUERY`, `DBMS_XLMSTORE`,
# `DBMS_XLMSAVE` and `DBMS_REDACT` – provide APIs to schedule jobs. The user
# `PUBLIC` should not be able to execute these packages.
# - The Oracle database `DBMS_SQL` package is used for running dynamic SQL
#   statements.
# - The `DBMS_XMLGEN` package takes an arbitrary SQL query as input, converts it
#   to XML format, and returns the result as a CLOB.
# - The Oracle package `DBMS_XMLQUERY` takes an arbitrary SQL query, converts it
#   to XML format, and returns the result. This package is similar to
#   `DBMS_XMLGEN`.
# - The `DBMS_XLMSTORE` package provides XML functionality. It accepts a table
#   name and XML as input to perform DML operations against the table.
# - The `DBMS_XLMSAVE` package provides XML functionality. It accepts a table name
#   and XML as input and then inserts into or updates that table.
# - The `DBMS_REDACT` package provides an interface to Oracle Data Redaction,
#   which enables you to mask (redact) data that is returned from queries issued
#   by low- privileged users or an application.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.1.1.6
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.1.1.6
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.1.1.6
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.1.1.6
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::execute_is_revoked_from_public_on_sql_injection_helper_packages: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::execute_is_revoked_from_public_on_sql_injection_helper_packages::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `execute_is_revoked_from_public_on_sql_injection_helper_packages` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param list
#    This is an internal list of objects to apply the control to.
#    Don't modify
#
# @param exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::execute_is_revoked_from_public_on_sql_injection_helper_packages (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT TABLE_NAME
         , PRIVILEGE
         , GRANTEE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_TAB_PRIVS A
     WHERE GRANTEE = 'PUBLIC'
       AND PRIVILEGE = 'EXECUTE'
       AND TABLE_NAME IN ( 'DBMS_SQL'
                         , 'DBMS_XMLGEN'
                         , 'DBMS_XMLQUERY'
                         , 'DBMS_XMLSTORE'
                         , 'DBMS_XMLSAVE'
                         , 'DBMS_AW'
                         , 'OWA_UTIL'
                         , 'DBMS_REDACT'
                         )
     ORDER BY CON_ID, TABLE_NAME
    |-QUERY

  ora_secured_setup { "execute_is_revoked_from_public_on_sql_injection_helper_packages validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'EXECUTE' is revoked from PUBLIC on 'sql injection helper' packages on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'EXECUTE' should be revoked from PUBLIC on 'sql injection helper' packages, but it's NOT",
  }
}
