#
# ora_secured::validators::exempt_access_policy_is_revoked_from_unauthorized_grantee
#
# @summary The Oracle database `EXEMPT ACCESS POLICY` keyword provides the user the
# capability to access all the table rows regardless of row-level security
# lockouts. Unauthorized grantees should not have that keyword assigned to them.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 5.2.8
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 5.2.8
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 5.2.8
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 5.2.8
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::exempt_access_policy_is_revoked_from_unauthorized_grantee: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::exempt_access_policy_is_revoked_from_unauthorized_grantee::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `exempt_access_policy_is_revoked_from_unauthorized_grantee` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude_users
#    The users to exclude from the control actions.
#
# @param exclude_roles
#    The roles to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::exempt_access_policy_is_revoked_from_unauthorized_grantee (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT GRANTEE
         , PRIVILEGE
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_SYS_PRIVS A
     WHERE PRIVILEGE = 'EXEMPT ACCESS POLICY'
       AND GRANTEE NOT IN (SELECT USERNAME FROM CDB_USERS WHERE ORACLE_MAINTAINED = 'Y')
       AND GRANTEE NOT IN (SELECT ROLE FROM CDB_ROLES WHERE ORACLE_MAINTAINED = 'Y')
    |-QUERY

  ora_secured_setup { "exempt_access_policy_is_revoked_from_unauthorized_grantee validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "No unprivileged users have 'EXEMPT ACCESS POLICY' role on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Unprivileged users should not have 'EXEMPT ACCESS POLICY' role, but SOME USERS HAVE IT",
  }
}
