#
# ora_secured::validators::inactive_account_time_is_less_than_or_equal_to_120
#
# @summary The `INACTIVE_ACCOUNT_TIME` setting determines the maximum number of days of
# inactivity (no logins at all) after which the account will be locked. The
# suggested value for this is 120 or less.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 3.9
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 3.9
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 3.9
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 3.9
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::inactive_account_time_is_less_than_or_equal_to_120: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::inactive_account_time_is_less_than_or_equal_to_120::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `inactive_account_time_is_less_than_or_equal_to_120` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude
#    The objects to exclude from the control actions.
#
# @param only
#    The list of object to only apply the control to.
#
# @param preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::inactive_account_time_is_less_than_or_equal_to_120 (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT P.PROFILE
         , P.RESOURCE_NAME
         , P.LIMIT
         , DECODE (P.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE P.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_PROFILES P
     WHERE TO_NUMBER(DECODE (P.LIMIT,'DEFAULT',   (SELECT DECODE(LIMIT,'UNLIMITED',9999,LIMIT)
                                                     FROM CDB_PROFILES
                                                    WHERE PROFILE='DEFAULT'
                                                      AND RESOURCE_NAME='INACTIVE_ACCOUNT_TIME'
                                                      AND CON_ID = P.CON_ID),
                                      'UNLIMITED','9999',
                                                  P.LIMIT)) > 120
       AND P.RESOURCE_NAME = 'INACTIVE_ACCOUNT_TIME'
       AND EXISTS ( SELECT 'X' FROM CDB_USERS U WHERE U.PROFILE = P.PROFILE )
     ORDER BY CON_ID, PROFILE, RESOURCE_NAME
    |-QUERY

  ora_secured_setup { "inactive_account_time_is_less_than_or_equal_to_120 validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'INACTIVE_ACCOUNT_TIME' is less than or equal to 120 on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'INACTIVE_ACCOUNT_TIME' should be less than or equal to 120, but it's NOT",
  }
}
