#
# ora_secured::validators::no_users_are_assigned_the_default_profile
#
# @summary Upon creation database users are assigned to the `DEFAULT` profile unless
# otherwise specified. No users should be assigned to that profile.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 4.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 4.4
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 4.4
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 4.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::no_users_are_assigned_the_default_profile: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::no_users_are_assigned_the_default_profile::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `no_users_are_assigned_the_default_profile` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param exclude
#    The objects to exclude from the control actions.
#
# @param profile_name
#    The name of the profile to create and to assign when a default profile is specified.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::no_users_are_assigned_the_default_profile (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT A.USERNAME
         , DECODE (A.CON_ID,0,(SELECT NAME FROM V$DATABASE),
                            1,(SELECT NAME FROM V$DATABASE),
                              (SELECT NAME FROM V$PDBS B WHERE A.CON_ID = B.CON_ID)) AS DATABASE
      FROM CDB_USERS A
     WHERE A.PROFILE = 'DEFAULT'
       AND A.ACCOUNT_STATUS = 'OPEN'
       AND A.ORACLE_MAINTAINED = 'N'
    |-QUERY

  ora_secured_setup { "no_users_are_assigned_the_default_profile validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "Profile 'DEFAULT' is not assigned to any user on ${title}":
    check                   => $query,
    expected_number_of_rows => 0,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "Profile 'DEFAULT' should not be assigned to any users, but SOME USERS HAVE IT",
  }
}
