#
# ora_secured::validators::remote_login_passwordfile_is_set_to_none
#
# @summary The `remote_login_passwordfile` setting specifies whether or not Oracle checks
# for a password file during login and how many databases can use the password
# file. The setting should have a value of `NONE` or in the event you are running
# DR/Data Guard, `EXCLUSIVE` is an allowable value.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.7
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.7
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.6
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.2.6
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::remote_login_passwordfile_is_set_to_none: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::remote_login_passwordfile_is_set_to_none::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `remote_login_passwordfile_is_set_to_none` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::remote_login_passwordfile_is_set_to_none (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT VALUE
      FROM V$SYSTEM_PARAMETER
     WHERE UPPER(NAME) = 'REMOTE_LOGIN_PASSWORDFILE'
       AND ( UPPER(VALUE) = 'NONE'
          OR UPPER(VALUE) = 'EXCLUSIVE' )
    |-QUERY

  ora_secured_setup { "remote_login_passwordfile_is_set_to_none validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'REMOTE_LOGIN_PASSWORDFILE' is set to NONE (or EXCLUSIVE) on ${title}":
    check                   => $query,
    expected_number_of_rows => 1,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'REMOTE_LOGIN_PASSWORDFILE' should be set to NONE (or EXCLUSIVE), but it's NOT",
  }
}
