#
# ora_secured::validators::sec_protocol_error_further_action_is_set_to_drop3
#
# @summary The `SEC_PROTOCOL_ERROR_FURTHER_ACTION` setting determines the Oracle server's
# response to bad/malformed packets received from the client. This setting should
# have a value of `(DROP,3)`, which will cause a connection to be dropped after
# three bad/malformed packets.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.2.13
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.2.12
# - [Oracle Database 19c CIS V1.0.0](/docs/ora_secured/cis/db19c_V1.0.0.html) - paragraph 2.2.11
# - [Oracle Database 19c CIS V1.1.0](/docs/ora_secured/cis/db19c_V1.1.0.html) - paragraph 2.2.11
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::sec_protocol_error_further_action_is_set_to_drop3: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::sec_protocol_error_further_action_is_set_to_drop3::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sec_protocol_error_further_action_is_set_to_drop3` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
# @param preferred_value
#    The preferred value to use.
#    Some controls allow multiple values. The control implement a default value, but when you want an other value, you can use this parameter.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::sec_protocol_error_further_action_is_set_to_drop3 (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  $query = @(QUERY)
    SELECT REPLACE(VALUE,',','_') AS VALUE
      FROM V$SYSTEM_PARAMETER
     WHERE UPPER(NAME) = 'SEC_PROTOCOL_ERROR_FURTHER_ACTION'
       AND REPLACE(VALUE,',','_') = '(DROP_3)'
    |-QUERY

  ora_secured_setup { "sec_protocol_error_further_action_is_set_to_drop3 validation on ${title}":
    ensure => present,
  }
  -> ora_validation { "'SEC_PROTOCOL_ERROR_FURTHER_ACTION' is set to '(DROP,3)' on ${title}":
    check                   => $query,
    expected_number_of_rows => 1,
    report_as               => $report_as,
    sid                     => $title,
    skip                    => $skip,
    control                 => easy_type::current_control(),
    fail_message            => "'SEC_PROTOCOL_ERROR_FURTHER_ACTION' should be set to '(DROP,3)', but it's NOT",
  }
}
