#
# ora_secured::validators::secure_register_is_set_to_tcps_or_ipc
#
# @summary The `SECURE_REGISTER_<listener_name>` setting specifies the protocols used to
# connect to the TNS listener. Each setting should have a value of either TCPS or
# IPC based on the needs for its protocol.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/ora_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Oracle Database 12c CIS V3.0.0](/docs/ora_secured/cis/db12c_V3.0.0.html) - paragraph 2.1.4
# - [Oracle Database 18c CIS V1.0.0](/docs/ora_secured/cis/db18c_V1.0.0.html) - paragraph 2.1.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `ora_secured::validators::secure_register_is_set_to_tcps_or_ipc: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `ora_secured::validators::secure_register_is_set_to_tcps_or_ipc::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_register_is_set_to_tcps_or_ipc` to the array value `ora_secured::skip_list` in your hiera data.
#
# @param title
#    The SID to apply the control to.
#    All controls need an SID to apply the control to. Here is a simple example:
#    ``` puppet
#    ora_secured::controls::control_name { 'DBSID':}
#    ```
#    In this example, the string DBSID is the sid to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define ora_secured::validators::secure_register_is_set_to_tcps_or_ipc (
  Boolean   $skip      = ora_secured::lookup_setting('skip', false),
  String[1] $report_as = ora_secured::lookup_setting('report_as', 'warning'),
) {
  ora_secured_setup { "secure_register_is_set_to_tcps_or_ipc validation on ${title}":
    ensure => present,
  }

  $installed_homes = $facts['ora_install_homes']
  $installed_homes['running_processes'].keys.each |$oracle_home| {
    unless $installed_homes.dig('running_processes', $oracle_home, 'listeners').length == 0 {
      $installed_homes['running_processes'][$oracle_home]['listeners'].each |$listener| {
        # lint:ignore:double_quoted_strings
        validation { "SECURE_REGISTER_${listener} is set in listener.ora in home ${oracle_home} for ${title}":
          check           => "egrep -i \"^SECURE_REGISTER_${listener}.*=.*(TCPS|IPC)\" ${oracle_home}/network/admin/listener.ora",
          path            => ['/bin'],
          expected_output => Regexp("(?i-mx:^SECURE_REGISTER_.*=.*(TCPS|IPC))"),
          report_as       => $report_as,
          skip            => $skip,
          control         => easy_type::current_control(),
          fail_message    => "SECURE_REGISTER_${listener} should be set in listener.ora in ${oracle_home}, but it's NOT",
          require         => Ora_secured_setup["secure_register_is_set_to_tcps_or_ipc validation on ${title}"],
        }
      # lint:endignore:double_quoted_strings
      }
    }
  }
}
